@@ -26,12 +26,6 @@
 #include <glib/gprintf.h>
 #include <Python.h>
 
-#if PY_VERSION_HEX < 0x02050000 && !defined(PY_SSIZE_T_MIN)
-typedef int Py_ssize_t;
-#define PY_SSIZE_T_MAX INT_MAX
-#define PY_SSIZE_T_MIN INT_MIN
-#endif
-
 typedef enum {
     CAJA_PYTHON_DEBUG_MISC = 1 << 0,
 } CajaPythonDebug;
